### Name: calib
### Title: Calculation of qPCR efficiency by dilution curve analysis with
###   an optional iterative search of the optimal threshold border
### Aliases: calib
### Keywords: models nonlinear

### ** Examples

## Define calibration curves,
## dilutions (or copy numbers) 
## and curves to be predicted.
## Do background subtraction using
## average of first 8 cycles
CAL <- modlist(reps, fluo = c(2, 6, 10, 14, 18, 22), backsub = 1:8)
COPIES <- c(100000, 10000, 1000, 100, 10, 1)
PRED <- modlist(reps, fluo = c(3, 7, 11), backsub = 1:8)

## conduct normal quantification using
## the second derivative maximum of 
## first curve
res <- calib(refcurve = CAL, predcurve = PRED, thresh = "cpD2", dil = COPIES) 

## using a defined treshold value
res <- calib(refcurve = CAL, predcurve = PRED, thresh = 0.5, dil = COPIES) 

## iterating the intercept with 50 steps
res <- calib(refcurve = CAL, predcurve = PRED, dil = COPIES, opt = "inter", 
              opt.step = c(50, 0)) 

## iterating the intercept/slope with 20 steps
## Not run: 
##D res <- calib(refcurve = CAL, predcurve = PRED, dil = COPIES, opt = "slope", 
##D               opt.step = c(20, 20)) 
## End(Not run)

## using replicates for reference curve
ml <- modlist(reps, model = l4)
DIL <- rep(10^(6:0),  each = 4) 
res <- calib(refcurve = ml, dil = DIL)    



