### Name: ratiocalc
### Title: Calculation of ratios/propagated errors/confidence
###   intervals/permutation p-values from qPCR runs with/without reference
###   data
### Aliases: ratiocalc
### Keywords: nonlinear

### ** Examples

## Only target sample and control,
## no reference, 4 replicates each
## individual efficiencies for error
## calculation
DAT <- pcrbatch(reps, 2:9, l4)
GROUP <- c("gs", "gs", "gs", "gs", "gc", "gc", "gc", "gc")
res <- ratiocalc(DAT, GROUP, which.eff = "sli", 
                 type.eff = "individual", which.cp = "cpD2")

## Typical for using individual efficiencies,
## this inflates the error. 95% confidence intervals 
## include 1 (no differential regulation) and errors are
## also extremely high (over 100%).
res$conf.Sim
res$conf.Perm
res$error.Prop/res$eval.Prop
res$pval.Perm

## Gets better using averaged efficiencies 
## over all replicates
res2 <- ratiocalc(DAT, GROUP, which.eff = "sli", 
                  type.eff = "mean.single", which.cp = "cpD2")
res2$conf.Sim
res2$conf.Perm
res2$error.Prop/res2$eval.Prop

## p-value indicates significant 
## upregulation in comparison to randomly reallocated 
## samples (similar to REST software)
res2$pval.Perm

## Using reference data.
## Toy example is same data as above
## but replicated as reference such
## that the ratio should be 1.
## Not run: 
##D DAT2 <- pcrbatch(reps, c(2:9, 2:9), l4)
##D GROUP2 <- c("gs", "gs", "gs", "gs", 
##D             "gc", "gc", "gc", "gc",
##D             "rs", "rs", "rs", "rs",
##D             "rc", "rc", "rc", "rc")
##D res3 <- ratiocalc(DAT2, GROUP2, which.eff = "sli", 
##D                   type.eff = "mean.single", which.cp = "cpD2")
##D res3$conf.Sim
##D res3$conf.Perm
##D res3$error.Prop/res3$eval.Prop
##D res3$pval.Perm
## End(Not run)

## Same as above, but reference data
## is mirrored such that the ratio 
## is squared.   
DAT3 <- pcrbatch(reps, c(2:9, 9:2), l4)
GROUP3 <- c("gs", "gs", "gs", "gs", 
            "gc", "gc", "gc", "gc",
            "rs", "rs", "rs", "rs",
            "rc", "rc", "rc", "rc")
res4 <- ratiocalc(DAT3, GROUP3, which.eff = "sli", 
                  type.eff = "mean.single", which.cp = "cpD2")
res4$conf.Sim
res4$conf.Perm
res4$error.Prop/res4$eval.Prop
res4$pval.Perm 

## Example without replicates 
## => no Monte-Carlo and permutations
## and no plots.
DAT <- pcrbatch(reps, 2:5, l4)
GROUP <- c("gs", "gc", "rs", "rc")
res5 <- ratiocalc(DAT, GROUP, which.eff = "sli", 
                  type.eff = "individual", which.cp = "cpD2")
res5$conf.Sim
res5$conf.Perm
res5$error.Prop/res4$eval.Prop
res5$pval.Perm 

## Compare 'propagate' to REST software
## using the data from the REST 2008
## manual (http://rest.gene-quantification.info/),
## Have to create dataframe with values as we do
## not use 'pcrbatch', but external cp's & eff's!
## Ties define random reallocation of crossing points
## keeping controls and samples together.
## See help for 'propagate'.
## Not run: 
##D EXPR <- expression((2.01^(cp.gc - cp.gs)/1.97^(cp.rc - cp.rs)))
##D cp.rc <- c(26.74, 26.85, 26.83, 26.68, 27.39, 27.03, 26.78, 27.32, NA, NA)
##D cp.rs <- c(26.77, 26.47, 27.03, 26.92, 26.97, 26.97, 26.07, 26.3, 26.14, 26.81)
##D cp.gc <- c(27.57, 27.61, 27.82, 27.12, 27.76, 27.74, 26.91, 27.49, NA, NA)
##D cp.gs <- c(24.54, 24.95, 24.57, 24.63, 24.66, 24.89, 24.71, 24.9, 24.26, 24.44)
##D DAT <- cbind(cp.rc, cp.rs, cp.gc, cp.gs)
##D res6 <- propagate(EXPR, DAT, do.sim = TRUE, do.perm = TRUE, 
##D                   perm.crit = "perm > init", ties = c(1, 2, 1, 2))
##D res6$conf.Sim
##D res6$conf.Perm
##D res6$eval.Prop
##D res6$error.Prop
##D res6$pval.Perm
## End(Not run)

## Does error propagation in qPCR quantitation make sense?
## In ratio calculations based on (E1^cp1)/(E2^cp2),
## only 2% error in each of the variables result in
## over 50% propagated error!
## Not run: 
##D x <- NULL
##D y <- NULL
##D for (i in seq(0, 0.1, by = 0.01)) {
##D       E1 <- c(1.7, 1.7 * i)
##D       cp1 <- c(15, 15 * i)
##D       E2 <- c(1.7, 1.7 * i)
##D       cp2 <- c(18, 18 * i)
##D       DF <- cbind(E1, cp1, E2, cp2)
##D       res <- propagate(expression((E1^cp1)/(E2^cp2)), DF, type = "stat", plot = FALSE)
##D       x <- c(x, i * 100)
##D       y <- c(y, (res$error.Prop/res$eval.Prop) * 100)
##D }
##D plot(x, y, xlim = c(0, 10), lwd = 2, xlab = "c.v. [%]", ylab = "c.v. (prop) [%]")
## End(Not run)



